@@ -1,5 +1,5 @@
 #
-# $Id: Request.pm,v 1.22 1998/01/06 09:57:15 aas Exp $
+# $Id: Request.pm,v 1.31 2003/10/16 10:54:16 gisle Exp $
 
 package HTTP::Request;
 
@@ -10,7 +10,7 @@ HTTP::Request - Class encapsulating HTTP Requests
 =head1 SYNOPSIS
 
  require HTTP::Request;
- $request = HTTP::Request->new(GET => 'http://www.oslonett.no/');
+ $request = HTTP::Request->new(GET => 'http://www.oslo.net/');
 
 =head1 DESCRIPTION
 
@@ -23,13 +23,12 @@ Instances of this class are usually passed to the C<request()> method
 of an C<LWP::UserAgent> object:
 
  $ua = LWP::UserAgent->new;
- $request = HTTP::Request->new(GET => 'http://www.oslonett.no/');
+ $request = HTTP::Request->new(GET => 'http://www.oslo.net/');
  $response = $ua->request($request);
 
 C<HTTP::Request> is a subclass of C<HTTP::Message> and therefore
-inherits its methods.  The inherited methods often used are header(),
-push_header(), remove_header(), headers_as_string() and content().
-See L<HTTP::Message> for details.
+inherits its methods.  The inherited methods most often used are header(),
+push_header(), remove_header(), and content(). See L<HTTP::Message> for details.
 
 The following additional methods are available:
 
@@ -39,26 +38,30 @@ The following additional methods are available:
 
 require HTTP::Message;
 @ISA = qw(HTTP::Message);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.22 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.31 $ =~ /(\d+)\.(\d+)/);
 
-use URI::URL ();
 use strict;
 
-=item $r = HTTP::Request->new($method, $url, [$header, [$content]])
+=item $r = HTTP::Request->new($method, $uri)
+
+=item $r = HTTP::Request->new($method, $uri, $header)
+
+=item $r = HTTP::Request->new($method, $uri, $header, $content)
 
 Constructs a new C<HTTP::Request> object describing a request on the
-object C<$url> using method C<$method>.  The C<$url> argument can be
-either a string, or a reference to a C<URI::URL> object.  The $header
+object C<$uri> using method C<$method>.  The C<$uri> argument can be
+either a string, or a reference to a C<URI> object.  The optional $header
 argument should be a reference to an C<HTTP::Headers> object.
+The optional $content argument should be a string.
 
 =cut
 
 sub new
 {
-    my($class, $method, $url, $header, $content) = @_;
+    my($class, $method, $uri, $header, $content) = @_;
     my $self = $class->SUPER::new($header, $content);
     $self->method($method);
-    $self->url($url);
+    $self->uri($uri);
     $self;
 }
 
@@ -68,52 +71,67 @@ sub clone
     my $self = shift;
     my $clone = bless $self->SUPER::clone, ref($self);
     $clone->method($self->method);
-    $clone->url($self->url);
+    $clone->uri($self->uri);
     $clone;
 }
 
 
-=item $r->method([$val])
+=item $r->method
 
-=item $r->url([$val])
+=item $r->method( $val )
 
-These methods provide public access to the member variables containing
-respectively the method of the request and the URL object of the
+=item $r->uri
+
+=item $r->uri( $val )
+
+These methods provide public access to the attributes containing
+respectively the method of the request and the URI object of the
 request.
 
-If an argument is given the member variable is given that as its new
+If an argument is given the attribute is given that as its new
 value. If no argument is given the value is not touched. In either
 case the previous value is returned.
 
-The url() method accept both a reference to a URI::URL object and a
+The method() method argument should be a string.
+
+The uri() method accept both a reference to a URI object and a
 string as its argument.  If a string is given, then it should be
-parseable as an absolute URL.
+parseable as an absolute URI.
 
 =cut
 
 sub method  { shift->_elem('_method', @_); }
 
-sub url
+sub uri
 {
     my $self = shift;
-    my $old = $self->{'_url'};
+    my $old = $self->{'_uri'};
     if (@_) {
-	my $url = shift;
-	if (!defined $url) {
+	my $uri = shift;
+	if (!defined $uri) {
 	    # that's ok
-	} elsif (ref $url) {
-	    $url = $url->abs;
+	} elsif (ref $uri) {
+	    Carp::croak("A URI can't be a " . ref($uri) . " reference")
+		if ref($uri) eq 'HASH' or ref($uri) eq 'ARRAY';
+	    Carp::croak("Can't use a " . ref($uri) . " object as a URI")
+		unless $uri->can('scheme');
+	    $uri = $uri->clone;
+	    unless ($HTTP::URI_CLASS eq "URI") {
+		# Argh!! Hate this... old LWP legacy!
+		eval { local $SIG{__DIE__}; $uri = $uri->abs; };
+		die $@ if $@ && $@ !~ /Missing base argument/;
+	    }
 	} else {
-	    $url = eval { URI::URL->new($url) };
+	    $uri = $HTTP::URI_CLASS->new($uri);
 	}
-	$self->{'_url'} = $url;
+	$self->{'_uri'} = $uri;
     }
     $old;
 }
 
-*uri = \&url;  # this is the same for now
+*url = \&uri;  # this is the same for now
 
-=item $r->as_string()
+=item $r->as_string
 
 Method returning a textual representation of the request.
 Mainly useful for debugging purposes. It takes no arguments.
@@ -126,9 +144,9 @@ sub as_string
     my @result;
     #push(@result, "---- $self -----");
     my $req_line = $self->method || "[NO METHOD]";
-    my $url = $self->url;
-    $url = (defined $url) ? $url->as_string : "[NO URL]";
-    $req_line .= " $url";
+    my $uri = $self->uri;
+    $uri = (defined $uri) ? $uri->as_string : "[NO URI]";
+    $req_line .= " $uri";
     my $proto = $self->protocol;
     $req_line .= " $proto" if $proto;
 
@@ -146,9 +164,13 @@ sub as_string
 
 =back
 
+=head1 SEE ALSO
+
+L<HTTP::Headers>, L<HTTP::Message>, L<HTTP::Request::Common>
+
 =head1 COPYRIGHT
 
-Copyright 1995-1997 Gisle Aas.
+Copyright 1995-2001 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
